@@ -1,5 +1,5 @@
 package CPAN::Perl::Releases;
-$CPAN::Perl::Releases::VERSION = '4.22';
+$CPAN::Perl::Releases::VERSION = '5.20200120';
 #ABSTRACT: Mapping Perl releases on CPAN to the location of the tarballs
 
 use strict;
@@ -249,6 +249,8 @@ our $data =
 "5.30.1-RC1" => { id => 'SHAY' },
 "5.30.1" => { id => 'SHAY' },
 "5.31.6" => { id => 'BINGOS' },
+"5.31.7" => { id => 'ATOOMIC' },
+"5.31.8" => { id => 'WOLFSAGE' },
 };
 
 sub perl_tarballs {
@@ -317,7 +319,7 @@ CPAN::Perl::Releases - Mapping Perl releases on CPAN to the location of the tarb
 
 =head1 VERSION
 
-version 4.22
+version 5.20200120
 
 =head1 SYNOPSIS
 
@@ -382,7 +384,7 @@ Chris Williams <chris@bingosnet.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by Chris Williams.
+This software is copyright (c) 2020 by Chris Williams.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
